;; Generated package description from xref.el  -*- no-byte-compile: t -*-
(define-package "xref" "1.4.0" "Cross-referencing commands" '((emacs "26.1")) :commit "f0ac4b7797fb16833a7a0c49593f36d88c69d2d5" :url "https://elpa.gnu.org/packages/xref.html")
